Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorNils Thuerey <nils@thuerey.de>2006-05-11 12:09:02 +0400
committerNils Thuerey <nils@thuerey.de>2006-05-11 12:09:02 +0400
commit6d935aee423c1dd9dfc16adb3049cf571a038ee3 (patch)
tree1e30a936590a27b18558c3af3cf031223b4117ad /source/blender/makesdna/DNA_object_fluidsim.h
parent66f0950d34d16d21d2457a7a38eb05b5c70658c4 (diff)
- New options for mesh voxelization: shell only (also
works for non closed objects), volume ("normal"/old way of doing it), and a combination of both: http://www10.informatik.uni-erlangen.de/~sinithue/blender/voltcomp_sm.jpg - Finally included bjornmose MSVC6 fixes - Added support for animated meshes, e.g. meshes with parented skeletons. Is enabled for obstacles with a new button. A simple example with Bassam's mancandy can be found here: http://www10.informatik.uni-erlangen.de/~sinithue/blender/fluid2_mancandy.mpg http://www10.informatik.uni-erlangen.de/~sinithue/blender/fluid2_mancandy.blend (Warning - keep meshes as simple as possible, e.g. turn off subsurf for baking. Export probably shoulb be further optimized.) - Changed handling of no/free/part slip obstacles, see: http://www10.informatik.uni-erlangen.de/~sinithue/blender/bndtcomp_sm.jpg - Removed surface particle option for upcoming release, needs more testing & tweaking - Added tracer particles instead (swimming along in the fluid) - Updated wiki (description of IPOs still missing).
Diffstat (limited to 'source/blender/makesdna/DNA_object_fluidsim.h')
-rw-r--r--source/blender/makesdna/DNA_object_fluidsim.h11
1 files changed, 8 insertions, 3 deletions
diff --git a/source/blender/makesdna/DNA_object_fluidsim.h b/source/blender/makesdna/DNA_object_fluidsim.h
index eb81ff76d5f..5ddfc22045d 100644
--- a/source/blender/makesdna/DNA_object_fluidsim.h
+++ b/source/blender/makesdna/DNA_object_fluidsim.h
@@ -97,18 +97,23 @@ typedef struct FluidsimSettings {
/* additional flags depending on the type, lower short contains flags
* to check validity, higher short additional flags */
short typeFlags;
- char domainNovecgen,dummyc;
+ /* switch off velocity genration, volume init type for fluid/obstacles (volume=1,shell=2,both=3) */
+ char domainNovecgen,volumeInitType;
/* boundary "stickiness" for part slip values */
float partSlipValue;
- /* particle generation - on if >0, then determines amount */
+
+ /* number of tracers to generate */
+ int generateTracers;
+ /* particle generation - on if >0, then determines amount (experimental...) */
float generateParticles;
/* smooth fluid surface? */
float surfaceSmoothing;
+
/* particle display - size scaling, and alpha influence */
float particleInfSize, particleInfAlpha;
/* testing vars */
- float farFieldSize,dummyf;
+ float farFieldSize;
/* save fluidsurface normals in mvert.no, and surface vertex velocities (if available) in mvert.co */
struct MVert *meshSurfNormals;